<?php
namespace Elementor;
/**
 * @package     WordPress
 * @subpackage  Pricing List Widget For Elementor
 * @author      support@themegum.com
 * @since       1.0.0
*/
defined('ABSPATH') or die();

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Scheme_Typography;
use Elementor\Icons_Manager;
use Elementor\Repeater;

class Price_Menu_List_Widget extends Widget_Base {


  public function __construct( $data = [], $args = null ) {
    parent::__construct( $data, $args );

    $is_type_instance = $this->is_type_instance();

    if ( ! $is_type_instance && null === $args ) {
      throw new \Exception( '`$args` argument is required when initializing a full widget instance.' );
    }

    add_action( 'elementor/element/before_section_start', [ $this, 'enqueue_script' ] );

    if ( $is_type_instance ) {
      $this->_register_skins();

      $widget_name = $this->get_name();

      /**
       * Widget skin init.
       *
       * Fires when Elementor widget is being initialized.
       *
       * The dynamic portion of the hook name, `$widget_name`, refers to the widget name.
       *
       * @since 1.0.0
       *
       * @param Widget_Base $this The current widget.
       */
      do_action( "elementor/widget/{$widget_name}/skins_init", $this );
    }
  }

  /**
   * Get widget name.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'temegum_price_list';
  }

  /**
   * Get widget title.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {

    return esc_html__( 'Pricing Menu List', 'price-menu-list-for-elementor' );
  }

  /**
   * Get widget icon.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'far fa-list-alt';
  }

  public function get_keywords() {
    return [ 'wordpress', 'widget', 'list','price','menu' ];
  }

  /**
   * Get widget categories.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [ 'temegum' ];
  }


  protected function _register_controls() {



    $repeater = new Repeater();

    $repeater->add_control(
      'list_title',
      [
        'label' => esc_html__( 'Title', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::TEXTAREA,
        'default' => esc_html__( 'Lorem ipsum dolor sit amet', 'price-menu-list-for-elementor' ),
        'rows' => 3,
        'label_block' => true,
      ]
    );

    $repeater->add_control(
      'list_sub_title',
      [
        'label' => esc_html__( 'Description', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::TEXTAREA,
        'default' => esc_html__( 'Lorem ipsum dolor sit amet', 'price-menu-list-for-elementor' ),
        'rows' => 3,
        'label_block' => true,
      ]
    );

    $repeater->add_control(
      'list_price',
      [
        'label' => esc_html__( 'Price', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::TEXT,
        'default' => '',
      ]
    );


    $repeater->add_control(
      'list_price_discount',
      [
        'label' => esc_html__( 'Discount Price', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::TEXT,
        'description' => esc_html__("Leave blank if no discount.", "price-menu-list-for-elementor"),
        'default' => '',
      ]
    );

    $repeater->add_control(
      'list_icon',
      [
        'label' => esc_html__( 'Icon', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::ICONS,
        'fa4compatibility' => 'icon',
      ]
    );

    $repeater->add_control(
      'image',
      [
        'label' => esc_html__( 'Image', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::MEDIA,
        'label_block' => true,
      ]
    );

    $repeater->add_control(
      'list_link',
      [
        'label' => esc_html__( 'Link', 'elementor' ),
        'type' => Controls_Manager::URL,
        'dynamic' => [
          'active' => true,
        ],
        'default' => [
          'url' => '',
        ],
        'separator' => 'before',
      ]
    );


    $this->start_controls_section(
      'section_price_items',
      [
        'label' => esc_html__( 'Price / Menu Items', 'price-menu-list-for-elementor' ),
      ]
    );


    $this->add_control(
      'lists',
      [
        'label' => esc_html__( 'Pricing Item', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::REPEATER,
        'fields' => $repeater->get_controls(),
        'default' => [
          [
            'list_title' => esc_html__( 'Menu #1', 'price-menu-list-for-elementor' ),
            'list_price' => 10,
          ],
          [
            'list_title' => esc_html__( 'Menu #2', 'price-menu-list-for-elementor' ),
            'list_price' => 12,
          ],
          [
            'list_title' => esc_html__( 'Menu #3', 'price-menu-list-for-elementor' ),
            'list_price' => 15,
          ],
          [
            'list_title' => esc_html__( 'Menu #4', 'price-menu-list-for-elementor' ),
            'list_price' => 20,
          ]
        ],
        'title_field' => '{{{ list_title }}}',
      ]
    );


    $this->add_control(
      'list_style',
      [
        'label' => esc_html__( 'Image Box', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'options' => [
              '' => esc_html__( 'Default', 'price-menu-list-for-elementor' ),
              'number' => esc_html__( 'Show Number', 'price-menu-list-for-elementor' ),
              'icon' => esc_html__( 'Show Ico', 'price-menu-list-for-elementor' ),
              'image' => esc_html__( 'Show Image', 'price-menu-list-for-elementor' )
        ],
        'default' => '',
      ]
    );

    $this->add_responsive_control(
      'list_layout',
      [
        'label' => esc_html__( 'Layout', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
          'horizontal' => [
            'title' => esc_html__( 'Horizontal', 'price-menu-list-for-elementor' ),
            'icon' => 'eicon-ellipsis-h',
          ],
          'vertical' => [
            'title' => esc_html__( 'Vertical', 'price-menu-list-for-elementor' ),
            'icon' => 'eicon-ellipsis-v',
          ],
        ],
        'default' => 'horizontal',
        'devices' => ['mobile'],
        'prefix_class' => 'feature-list-%s-layout-',
      ]
    );

    $this->end_controls_section();

/*
 * style params
 */

    $this->start_controls_section(
      'section_list_section_style',
      [
        'label' => esc_html__( 'List', 'price-menu-list-for-elementor' ),
        'tab'   => Controls_Manager::TAB_STYLE,
      ]
    );    

    $this->add_responsive_control(
      'list_space',
      [
        'label' => esc_html__( 'Spacing', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
          ],
          'em' => [
            'min' => 0,
            'max' => 20,
          ],
        ],
        'size_units' => [ 'px', 'em'],
        'default' => [
          'size' => 1,
          'unit' => 'em'
        ],
        'selectors' => [
          '{{WRAPPER}} .feature' => 'margin-bottom: calc( {{SIZE}}{{UNIT}} / 2 );margin-top: calc( {{SIZE}}{{UNIT}} /2 );',
        ],
      ]
    );


    $this->add_responsive_control(
      'content_align',
      [
        'label' => esc_html__( 'Aligment', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
          'flex-start' => [
            'title' => esc_html__( 'Top', 'price-menu-list-for-elementor' ),
            'icon' => 'eicon-v-align-top',
          ],
          'center' => [
            'title' => esc_html__( 'Middle', 'price-menu-list-for-elementor' ),
            'icon' => 'eicon-v-align-middle',
          ],
          'strech' => [
            'title' => esc_html__( 'Strech', 'price-menu-list-for-elementor' ),
            'icon' => 'eicon-v-align-stretch',
          ],
          'flex-end' => [
            'title' => esc_html__( 'Bottom', 'price-menu-list-for-elementor' ),
            'icon' => 'eicon-v-align-bottom',
          ],
        ],
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .feature' => 'align-items: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'feature_list_background',
      [
        'label' => esc_html__( 'Background', 'price-menu-list-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .feature' => 'background: {{VALUE}};',
        ],
        'separator' =>'after'
      ]
    );


    $this->add_responsive_control(
      'feature_list_padding',
      [
        'label' => esc_html__( 'Padding', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em' ],
        'selectors' => [
          '{{WRAPPER}} .feature' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
      'feature_list_radius',
      [
        'label' => esc_html__( 'Radius', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .feature' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'feature_list_border',
        'selector' => '{{WRAPPER}} .feature',
        'separator'=>'before'
      ]
    );


    $this->add_group_control(
      Group_Control_Box_Shadow::get_type(),
      [
        'name' => 'feature_list_shadow',
        'selector' => '{{WRAPPER}} .feature',
      ]
    );

    $this->end_controls_section();


    $this->start_controls_section(
        'section_list_bullet_styles',
        [
          'label' => esc_html__( 'Image Box', 'price-menu-list-for-elementor' ),
          'tab'   => Controls_Manager::TAB_STYLE,
          'condition' => [
            'list_style' => ['number','icon'],
          ]
        ]
      );    

    $this->add_responsive_control(
      'list_bullet_size',
      [
        'label' => esc_html__( 'Number/Icon Size', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'max' => 200,
            'step'=> 1
          ],
        ],
        'default' => [
          'size' => '',
          'unit' => 'px'
        ],
        'selectors' => [
          '{{WRAPPER}} .feature .feature-marker span' => 'font-size: {{SIZE}}px;',
        ],
        'condition' => [
          'list_style' => ['number','icon'],
        ]
      ]
    );

    $this->add_control(
      'list_bullet_color',
      [
        'label' => esc_html__( 'Number/Icon Color', 'price-menu-list-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .feature .feature-marker' => 'color: {{VALUE}};',
        ],
        'condition' => [
          'list_style' => ['number','icon'],
        ],
        'separator' =>'after'
      ]
    );


    $this->add_responsive_control(
      'list_box_size',
      [
        'label' => esc_html__( 'Box Size', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'max'=>1000,
            'step'=> 1
          ],
        ],
        'default' => [
          'size' => 60,
          'unit' => 'px'
        ],
        'selectors' => [
          '{{WRAPPER}} .feature .feature-marker' => 'width: {{SIZE}}px;height: {{SIZE}}px;',
        ],
        'condition' => [
          'list_style!' => '',
        ],
      ]
    );


    $this->add_responsive_control(
      'list_box_space',
      [
        'label' => esc_html__( 'Spacing', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
          ],
          'em' => [
            'min' => 0,
            'max' => 20,
            'step' => 0.1
          ],
        ],
        'size_units' => [ 'px', 'em'],
        'default' => [
          'size' => 1,
          'unit' => 'em'
        ],
        'condition' => [
          'list_style!' => '',
        ],
        'selectors' => [
          '{{WRAPPER}} .feature .feature-marker' => 'margin-right: {{SIZE}}{{UNIT}};',
          '[data-elementor-device-mode=mobile] {{WRAPPER}}.feature-list--mobile-layout-vertical .feature .feature-marker' => 'margin-right: 0 !important;margin-bottom: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_control(
      'list_bullet_bgcolor',
      [
        'label' => esc_html__( 'Background', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'condition' => [
          'list_style!' => '',
        ],
        'selectors' => [
          '{{WRAPPER}} .feature .feature-marker' => 'background: {{VALUE}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'list_bullet_border',
        'selector' => '{{WRAPPER}} .feature .feature-marker',
        'condition' => [
          'list_style!' => '',
        ],
        'separator' => 'before'
      ]
    );

    $this->add_control(
      'list_bullet_radius',
      [
        'label' => esc_html__( 'Box Radius', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .feature .feature-marker' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'condition' => [
          'list_style!' => '',
        ]
      ]
    );

    $this->add_group_control(
      Group_Control_Box_Shadow::get_type(),
      [
        'name' => 'list_bullet_shadow',
        'selector' => '{{WRAPPER}} .feature .feature-marker',
        'condition' => [
          'list_style' => ['number','icon'],
        ]
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'section_list_title_style',
      [
        'label' => esc_html__( 'Title', 'price-menu-list-for-elementor' ),
        'tab'   => Controls_Manager::TAB_STYLE,
      ]
    );    

    $this->add_responsive_control(
      'feature_list_title_padding',
      [
        'label' => esc_html__( 'Padding', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em' ],
        'selectors' => [
          '{{WRAPPER}} .feature .feature-name' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'default' => [
          'size' => 1,
          'unit' => 'em'
        ],
        'separator' => 'after'
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'typography_list_title',
        'selector' => '{{WRAPPER}} .feature .feature-title',
      ]
    );

    $this->add_control(
      'list_title_color',
      [
        'label' => esc_html__( 'Color', 'price-menu-list-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .feature .feature-title' => 'color: {{VALUE}};',
        ]
      ]
    );


    $this->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'list_title_shadow',
        'selector' => '{{WRAPPER}} .feature .feature-title',
      ]
    );

    $this->add_control(
      'list_title_line',
      [
        'label' => esc_html__( 'Line Decoration', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Show', 'price-menu-list-for-elementor' ),
        'label_off' => esc_html__( 'Hide', 'price-menu-list-for-elementor' ),
        'default' => 'yes',
        'separator' => 'before',
      ]
    );


    $this->add_control(
      'list_title_line_style', 
      [
        'label' => esc_html__( 'Type', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'options' => [
          'solid' => esc_html__( 'Solid', 'price-menu-list-for-elementor' ),
          'double' => esc_html__( 'Double', 'price-menu-list-for-elementor' ),
          'dotted' => esc_html__( 'Dotted', 'price-menu-list-for-elementor' ),
          'dashed' => esc_html__( 'Dashed', 'price-menu-list-for-elementor' ),
          'groove' => esc_html__( 'Groove', 'price-menu-list-for-elementor' ),
        ],
        'condition' => [
          'list_title_line' => 'yes',
        ],
        'default' => 'solid',
        'selectors' => [
          '{{WRAPPER}} .temegum-features-list.title-with-line .feature .feature-title:after' => 'border-top-style: {{VALUE}};'
        ]
      ]
    );


    $this->add_control(
      'list_title_line_color',
      [
        'label' => esc_html__( 'Color', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'condition' => [
          'list_title_line' => 'yes',
        ],
        'selectors' => [
          '{{WRAPPER}} .temegum-features-list.title-with-line .feature .feature-title:after' => 'border-top-color: {{VALUE}};'
        ],
      ]
    );


    $this->add_control(
      'list_title_line_size',
      [
        'label' => esc_html__( 'Size', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 1,
          ],
        ],
        'default' => [
          'size' => 1,
          'unit' => 'px'
        ],
        'condition' => [
          'list_title_line' => 'yes',
        ],
        'selectors' => [
          '{{WRAPPER}} .temegum-features-list.title-with-line .feature .feature-title:after' => 'border-top-width: {{SIZE}}px;',
        ],
      ]
    );

    $this->end_controls_section();


    $this->start_controls_section(
      'section_list_desc_style',
      [
        'label' => esc_html__( 'Description', 'price-menu-list-for-elementor' ),
        'tab'   => Controls_Manager::TAB_STYLE,
      ]
    );    

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'typography_list_desc',
        'selector' => '{{WRAPPER}} .feature .feature-subtitle',
      ]
    );

    $this->add_control(
      'list_desc_color',
      [
        'label' => esc_html__( 'Color', 'price-menu-list-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .feature .feature-subtitle' => 'color: {{VALUE}};',
        ]
      ]
    );


    $this->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'list_desc_shadow',
        'selector' => '{{WRAPPER}} .feature .feature-subtitle',
      ]
    );


    $this->add_control(
      'list_desc_spacing',
      [
        'label' => esc_html__( 'Spacing', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
            'step'=> 1
          ],
          'em' => [
            'min' => 0,
            'max' => 20,
            'step'=> 0.1
          ],
        ],
        'size_units' => [ 'px', 'em' ],
        'default' => [
          'size' => 0.3,
          'unit' => 'em'
        ],
        'selectors' => [
          '{{WRAPPER}} .feature .feature-subtitle' => 'margin-top: {{SIZE}}{{UNIT}};',
        ]
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
        'section_list_value_styles',
        [
          'label' => esc_html__( 'Price', 'price-menu-list-for-elementor' ),
          'tab'   => Controls_Manager::TAB_STYLE,
        ]
      );    

      $this->add_group_control(
        Group_Control_Typography::get_type(),
        [
          'name' => 'typography_list_value',
          'selector' => '{{WRAPPER}} .feature .feature-price',
        ]
      );


      $this->add_control(
        'list_value_color',
        [
          'label' => esc_html__( 'Color', 'price-menu-list-for-elementor' ),
          'type' =>  Controls_Manager::COLOR,
          'default' => '',
          'selectors' => [
            '{{WRAPPER}} .feature .feature-price' => 'color: {{VALUE}};',
          ]
        ]
      );


    $this->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'list_value_shadow',
        'selector' => '{{WRAPPER}} .feature .feature-price',
      ]
    );

    $this->add_responsive_control(
      'list_value_space',
      [
        'label' => esc_html__( 'Spacing', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
          ],
          'em' => [
            'min' => 0,
            'max' => 20,
            'step' => 0.1
          ],
        ],
        'size_units' => [ 'px', 'em'],
        'default' => [
          'size' => 1,
          'unit' => 'em'
        ],
        'selectors' => [
          '{{WRAPPER}} .feature .feature-price' => 'margin-left: {{SIZE}}{{UNIT}};',
          '[data-elementor-device-mode=mobile] {{WRAPPER}}.feature-list--mobile-layout-vertical .feature .feature-price' => 'margin-left: 0 !important;margin-top: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_responsive_control(
      'list_value_offset',
      [
        'label' => esc_html__( 'Offset Top', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
          ],
        ],
        'default' => [
          'size' => '',
          'unit' => 'px'
        ],
        'selectors' => [
          '{{WRAPPER}} .feature .feature-price' => 'margin-top: {{SIZE}}{{UNIT}};',
        ],
      ]
    );


    $this->add_control(
      'list_value_title',
      [
        'label' => esc_html__( 'Discount', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::HEADING,
        'separator' => 'before',
      ]
    );


      $this->add_group_control(
        Group_Control_Typography::get_type(),
        [
          'name' => 'typography_list_discount',
          'selector' => '{{WRAPPER}} .feature .original-price',
        ]
      );


      $this->add_control(
        'list_discount_color',
        [
          'label' => esc_html__( 'Color', 'price-menu-list-for-elementor' ),
          'type' =>  Controls_Manager::COLOR,
          'default' => '',
          'selectors' => [
            '{{WRAPPER}} .feature .original-price' => 'color: {{VALUE}};',
          ]
        ]
      );


    $this->add_responsive_control(
      'list_discount_offset',
      [
        'label' => esc_html__( 'Offset Top', 'price-menu-list-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => -200,
            'max' => 200,
          ],
        ],
        'default' => [
          'size' => '',
          'unit' => 'px'
        ],
        'selectors' => [
          '{{WRAPPER}} .feature .original-price' => 'margin-top: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->end_controls_section();


  }

  protected function render() {

    $settings = $this->get_settings_for_display();

      extract( $settings );

      if(!count($lists)) return;


      $compile  = '<ul class="temegum-features-list'.($list_title_line=='yes'? ' title-with-line':'').'" dir="ltr">';

      $i = 1;

      foreach ($lists as $index => $list) {
        
      
             $compile.='<li class="elementor-repeater-item-'.$list['_id'].' feature">';

            if ( ! empty( $list['list_link']['url'] ) ) {

                  $repeater_link_key = $this->get_repeater_setting_key( 'list_link', 'lists', $index );
                  $this->add_link_attributes( $repeater_link_key, $list['list_link'] );
            }

            if($list_style !=''){
               
               $marker_html = '';

                switch ($list_style) {
                  case 'image':

                        if($list['image']!='' && ( $image= wp_get_attachment_image_src($list['image']['id'],'medium') )){

                          $image_alt_text = get_post_meta($list['image']['id'], '_wp_attachment_image_alt', true);
                          $marker_html = '<img src="'.esc_url($image[0]).'" alt="'.esc_attr($image_alt_text).'" />';
                        }

                    break;
                  case 'icon':


                        $list_iconHTML = '';

                        if(!empty($list['list_icon']['value'])){
                            ob_start();
                            Icons_Manager::render_icon( $list['list_icon'], [ 'aria-hidden' => 'true' ] );
                            $list_iconHTML = ob_get_clean();
                        }

                        $marker_html = $list_iconHTML;

                    break;
                  default:
                       $marker_html = $i;
                    break;
                }

              if($marker_html !==''){
                $compile .= '<span class="feature-marker bullet-'.$list_style.'"><span>'.$marker_html.'</span></span>';

              }

            }

             $compile .= '<span class="feature-name">';

             if($list['list_title'] !=''){

                $repeater_title_key = $this->get_repeater_setting_key( 'list_title', 'lists', $index );
                $this->add_inline_editing_attributes( $repeater_title_key );
                $this->add_render_attribute( $repeater_title_key , 'class', 'feature-title' );

                $title = $list['list_title'];

                if ( ! empty( $list['list_link']['url'] ) ) {

                  $title = sprintf( '<a %1$s>%2$s</a>', $this->get_render_attribute_string( $repeater_link_key ), $title );
                }

                $compile .= '<span '.$this->get_render_attribute_string( $repeater_title_key ).'>'.$title.'</span>';

             }

             if($list['list_sub_title'] !=''){

                $repeater_subtitle_key = $this->get_repeater_setting_key( 'list_sub_title', 'lists', $index );
                $this->add_inline_editing_attributes( $repeater_subtitle_key );
                $this->add_render_attribute( $repeater_subtitle_key , 'class', 'feature-subtitle' );

                $compile .= '<span '.$this->get_render_attribute_string( $repeater_subtitle_key ).'>'.esc_html($list['list_sub_title']).'</span>';
             }

             $compile .= '</span>';

             if($list['list_price'] !=''){

                $repeater_price_key = $this->get_repeater_setting_key( 'list_price', 'lists', $index );
                $repeater_price_discount_key = $this->get_repeater_setting_key( 'list_price_discount', 'lists', $index );

                $this->add_inline_editing_attributes( $repeater_price_key );
                $this->add_inline_editing_attributes( $repeater_price_discount_key );

                if($list['list_price_discount']!=''){
                  $compile .= '<span class="feature-price"><span '.$this->get_render_attribute_string( $repeater_price_discount_key ).'>'.esc_html($list['list_price_discount']).'</span><span class="original-price"><del '.$this->get_render_attribute_string( $repeater_price_key ).'>'.esc_html($list['list_price']).'</del></span></span>';
                }
                else{
  
                  $compile .= '<span class="feature-price"><span '.$this->get_render_attribute_string( $repeater_price_key ).'>'.esc_html($list['list_price']).'</span></span>';
                }
             }

             $compile.='</li>';

             $i++;
      }


      $compile .= '</ul>';

    print $compile;

  }
 
  protected function content_template() {
    ?>
<ul class="temegum-features-list <# if ( settings.list_title_line =='yes' ){#>title-with-line<# } #>" dir="ltr"><# 
    if ( settings.lists ) {

    var i = 1;

    _.each( settings.lists, function( list, index) {
      
          var list_prices = marker_html = '', list_title = list.list_title, list_sub_title = list.list_sub_title;

          var repeater_title_key = view.getRepeaterSettingKey( 'list_title', 'lists', index );
          view.addInlineEditingAttributes( repeater_title_key );
          view.addRenderAttribute( repeater_title_key , 'class', 'feature-title' );

          var repeater_subtitle_key = view.getRepeaterSettingKey( 'list_sub_title', 'lists', index );
          view.addInlineEditingAttributes( repeater_subtitle_key );
          view.addRenderAttribute( repeater_subtitle_key , 'class', 'feature-subtitle' );

          var repeater_price_key = view.getRepeaterSettingKey( 'list_price', 'lists', index );
          var repeater_price_discount_key = view.getRepeaterSettingKey( 'list_price_discount', 'lists', index );

          view.addInlineEditingAttributes( repeater_price_key );
          view.addInlineEditingAttributes( repeater_price_discount_key );


          if(list.list_price_discount !=''){

              list_prices = '<span ' + view.getRenderAttributeString( repeater_price_discount_key ) + '>'+ list.list_price_discount + '</span><span class="original-price"><del '+view.getRenderAttributeString( repeater_price_key )+'>' + list.list_price + '</del></span>';

           }
           else{

              list_prices = '<span ' + view.getRenderAttributeString( repeater_price_key ) + '>'+ list.list_price + '</span>';
           }

           if(settings.list_style!=''){

            if(settings.list_style == 'image'){

              if ( list.image.url ) {
                  var image = {
                    id: list.image.id,
                    url: list.image.url,
                    size: 'medium',
                    dimension: [],
                    model: view.getEditModel()
                  };

                var image_url = elementor.imagesManager.getImageUrl( image );
                marker_html = '<img src="' + image_url + '"  />';

              }

            }
            else if(settings.list_style == 'icon'){
              if(list.list_icon){
                var iconsHTML = elementor.helpers.renderIcon( view, list.list_icon, { 'aria-hidden': true }, 'i' , 'object' );
                marker_html = iconsHTML.rendered ? iconsHTML.value : '';
              }
            }
            else{
              marker_html = i;
            }

           }

          #>
          <li class="elementor-repeater-item-{{ list._id }} feature"><# if(marker_html !==''){#><span class="feature-marker bullet-{{{ settings.list_style }}}"><span>{{{ marker_html }}}</span></span><# } #><span class="feature-name"><span {{{ view.getRenderAttributeString( repeater_title_key ) }}}>{{{ list_title }}}</span><span {{{ view.getRenderAttributeString( repeater_subtitle_key ) }}}>{{{ list_sub_title }}}</span></span><span class="feature-price">{{{list_prices}}}</span></li>
    <# i++; });
    }
    #>
</ul>
    <?php
  }

  public function enqueue_script( ) {
    wp_enqueue_style( 'temegum-pricing-menu-list',PMLST_ELEMENTOR_URL."css/style.css",array());
  }

}


// Register widget
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Price_Menu_List_Widget() );

?>